package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.intevation.artifacts.CallContext;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifactdatabase.ProtocolUtils;
import de.intevation.artifactdatabase.data.StateData;

import de.intevation.flys.artifacts.model.River;
import de.intevation.flys.artifacts.model.RiverFactory;
import de.intevation.flys.artifacts.resources.Resources;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class RiverSelect extends DefaultState {

    /** The logger used in this class. */
    private static Logger logger = Logger.getLogger(RiverSelect.class);

    /**
     * The default constructor that initializes an empty State object.
     */
    public RiverSelect() {
    }


    /**
     * Initialize the state based on the state node in the configuration.
     *
     * @param config The state configuration node.
     */
    public void setup(Node config) {
        super.setup(config);
    }


    protected Element createData(
        XMLUtils.ElementCreator cr,
        StateData   data,
        CallContext context)
    {
        Element select = ProtocolUtils.createArtNode(
            cr, "select",
            new String[] { "uiprovider" },
            new String[] { "select_with_map" });
        cr.addAttr(select, "name", data.getName());

        Element label = ProtocolUtils.createArtNode(
            cr, "label", null, null);

        Element choices = ProtocolUtils.createArtNode(
            cr, "choices", null, null);

        label.setTextContent(Resources.getMsg(
            context.getMeta(),
            getID(),
            getID()));

        return select;
    }


    protected Element[] createItems(
        XMLUtils.ElementCreator cr,
        String      name,
        CallContext context)
    {
        List<River> rivers = RiverFactory.getRivers();
        Element[] items    = new Element[rivers.size()];

        int idx = 0;
        for (River river: rivers) {
            items[idx++] = createRiverItem(cr, river);
        }

        return items;
    }


    /**
     * This method creates a node that represents a river item. This node
     * contains the label and the value that describe the river.
     *
     * @param cr The ElementCreator.
     * @param river The river.
     *
     * @return the element that contains the information about the river.
     */
    protected Element createRiverItem(XMLUtils.ElementCreator cr, River river) {
        Element item  = ProtocolUtils.createArtNode(cr, "item", null, null);
        Element label = ProtocolUtils.createArtNode(cr, "label", null, null);
        Element value = ProtocolUtils.createArtNode(cr, "value", null, null);

        label.setTextContent(river.getName());
        value.setTextContent(river.getName());

        item.appendChild(label);
        item.appendChild(value);

        return item;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
